
1.0.0a2 (2017-03-30)
#####################

Changes since 1.0.0a1 (2017-03-11).

Bug Fixes
$$$$$$$$$$

* Closed `#403 <https://github.com/biocommons/hgvs/issues/403/>`_: Add missing import [`3e363f57edf8 <https://github.com/biocommons/hgvs/commit/3e363f57edf8>`_]
* Closed `#409 <https://github.com/biocommons/hgvs/issues/409/>`_: Fix bug in normalizer when normalizing ident variant that is written as delins [`94607ecc30da <https://github.com/biocommons/hgvs/commit/94607ecc30da>`_]
* Closed `#415 <https://github.com/biocommons/hgvs/issues/415/>`_: Limit assembly mapper to NC_ accessions [`6056fd4414df <https://github.com/biocommons/hgvs/commit/6056fd4414df>`_]

New Features
$$$$$$$$$$$$$

* Closed `#404 <https://github.com/biocommons/hgvs/issues/404/>`_: Implement max_ref_length in formatter and don't show reference sequence by default

Internal and Developer Changes
$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$

* 396-use enum34 for datums (`#411 <https://github.com/biocommons/hgvs/issues/411/>`_)
